@@ -93,10 +93,6 @@ def test_amount_zero():
 
 def test_transfer_to_self():
     return
-    import sys
-    if not sys.version.startswith("3.6"):
-        #only test under 3.6, prevent parallel test to one account error.
-        return
     wallet = libra_client.WalletLibrary.recover('test/test.wallet')
     a0 = wallet.accounts[0]
     c = libra_client.Client("testnet")
@@ -104,8 +100,7 @@ def test_transfer_to_self():
     if balance == 0:
         c.mint_coins(a0.address, 1000000, is_blocking=True)
     ret = c.transfer_coin(a0, a0.address, 1, is_blocking=True)
-    proto, _ = c.get_account_transaction_proto(ret.raw_txn.sender, ret.raw_txn.sequence_number, True)
-    stx = Transaction.deserialize(proto.transaction.transaction).value
+    stx = c.get_account_transaction(ret.raw_txn.sender, ret.raw_txn.sequence_number, True)
     assert proto.version > 1
     assert len(proto.events.events) == 2
     assert proto.proof.transaction_info.major_status == 4001
